@@ -35,7 +35,7 @@ sub null_timestamp { '0000-00-00 00:00:00.00000' }
 sub min_timestamp  { '0001-01-01 00:00:00.00000' }
 sub max_timestamp  { '9999-12-31 23:59:59.99999' }
 
-sub last_insertid_from_sth { $_[1]->{ix_sqlerrd}[1] }
+sub last_insertid_from_sth { $_[1]->{'ix_sqlerrd'}[1] }
 
 sub generate_primary_key_values { return; }
 
@@ -390,11 +390,11 @@ Rose::DB::Informix - Informix driver class for Rose::DB.
 
 =head1 DESCRIPTION
 
-This is the subclass that C<Rose::DB> blesses an object into when the C<driver> is "Informix".  This mapping of drivers to class names is configurable.  See the documentation for C<Rose::DB>'s C<new()> and C<driver_class()> methods for more information.
+This is the subclass that L<Rose::DB> blesses an object into when the C<driver> is "Informix".  This mapping of drivers to class names is configurable.  See the documentation for L<Rose::DB>'s C<new()> and C<driver_class()> methods for more information.
 
-Using this class directly is not recommended.  Instead, use C<Rose::DB> and let it bless objects into the appropriate class for you, according to its C<driver_class()> mappings.
+Using this class directly is not recommended.  Instead, use L<Rose::DB> and let it bless objects into the appropriate class for you, according to its C<driver_class()> mappings.
 
-This class inherits from C<Rose::DB>.  B<Only the methods that are new or have  different behaviors are documented here.>  See the C<Rose::DB> documentation for information on the inherited methods.
+This class inherits from L<Rose::DB>.  B<Only the methods that are new or have  different behaviors are documented here.>  See the L<Rose::DB> documentation for information on the inherited methods.
 
 =head1 CLASS METHODS
 
